#!/usr/bin/perl
# 2ptrw.pl: convert an ascii text file, where records end with LF (0xA)
# or CR (0xD) or LFCR or CRLF or any other combination of CR's and LF's 
# to a ascii papertape for P800 where records end with LF (0xA) CR (0xD).
# Records with only CR(s)/LF(s) are deleted (empty records).
#
# Usage: 2ptrw.pl <textfile>
# produces <name>.ptr
use strict;
use bytes;
my $s;
my $l;
my $c;
my $file = shift(@ARGV);
if ($file eq "")
{
    print "No filename\n";
    exit;
}
my @fn = split(/\./,$file);
my $fileout = $fn[0] . ".ptr";
if( -e $file)
{
	open (IN,$file) || die "cannot open file $file: $!";
	print "Convert $file to $fileout\n";
}
else
{
    print "$file is not existing\n";
	exit;
}
open (OUT,">", $fileout) || die "cannot open file $fileout: $!";

while($s=<IN>)
{
        $l=length($s);
        while($l>0)
        {
        	$c=substr($s,$l-1,1);
        	$c = unpack("C", $c);
        	$c = $c & 0xFF;
        
        	if(($c == 0xA) || ($c == 0xD))
        	{
        		# strip
        		$s=substr($s,0,$l-1);
        		$l=length($s);
        	}
        	else
        	{
        		last;
        	}
        }
        
        if($l>0)
        {
        	# ignore empty records
        	$s = $s . chr(0xA) . chr(0xD);
        	syswrite OUT, $s;
        }
	
	if(substr($s,0,4) eq ':EOF')
	{
		last;
	}
}
print "$file is converted\n";
close (IN) || die "can't close $file: $!";
close (OUT) || die "can't close $fileout: $!";

